@@ -2,7 +2,7 @@ import React, {Component} from 'react';
 import PropTypes from 'prop-types';
 import PropertyLengthMeasure from '../../../../catalog/properties/property-lenght-measure';
 
-export default function HoleAttributesEditor({element, onUpdate, attributeFormData}, {translator}) {
+export default function HoleAttributesEditor({element, onUpdate, attributeFormData, state}, {translator}) {
   let offsetA = attributeFormData.has('offsetA') ? attributeFormData.get('offsetA') : element.offsetA;
   let offsetB = attributeFormData.has('offsetB') ? attributeFormData.get('offsetB') : element.offsetA;
 
@@ -11,11 +11,13 @@ export default function HoleAttributesEditor({element, onUpdate, attributeFormDa
       value={offsetA}
       onUpdate={mapped => onUpdate('offsetA', mapped)}
       configs={{label: 'Offset 1', min: 0, max: Infinity}}
+      state={state}
     />
     <PropertyLengthMeasure
       value={offsetB}
       onUpdate={mapped => onUpdate('offsetB', mapped)}
       configs={{label: 'Offset 2', min: 0, max: Infinity}}
+      state={state}
     />
   </div>;
 }
@@ -23,7 +25,8 @@ export default function HoleAttributesEditor({element, onUpdate, attributeFormDa
 HoleAttributesEditor.propTypes = {
   element: PropTypes.object.isRequired,
   onUpdate: PropTypes.func.isRequired,
-  attributeFormData: PropTypes.object.isRequired
+  attributeFormData: PropTypes.object.isRequired,
+  state: PropTypes.object.isRequired
 };
 
 HoleAttributesEditor.contextTypes = {
