@@ -1,6 +1,7 @@
 "use strict";
 
 import React from 'react';
+import PropTypes from 'prop-types';
 import ReactDOM from 'react-dom';
 import * as Three from 'three';
 import {parseData, updateScene} from './scene-creator';
@@ -96,7 +97,7 @@ export default class Scene3DViewer extends React.Component {
         raycaster.setFromCamera(mouse, camera);
         let intersects = raycaster.intersectObjects(toIntersect, true);
 
-        if (intersects.length > 0) {
+        if (intersects.length > 0 && !(isNaN(intersects[0].distance))) {
           intersects[0].object.interact && intersects[0].object.interact();
         } else {
           this.context.projectActions.unselectAll();
@@ -282,16 +283,16 @@ export default class Scene3DViewer extends React.Component {
 }
 
 Scene3DViewer.propTypes = {
-  state: React.PropTypes.object.isRequired,
-  width: React.PropTypes.number.isRequired,
-  height: React.PropTypes.number.isRequired
+  state: PropTypes.object.isRequired,
+  width: PropTypes.number.isRequired,
+  height: PropTypes.number.isRequired
 };
 
 Scene3DViewer.contextTypes = {
-  areaActions: React.PropTypes.object.isRequired,
-  holesActions: React.PropTypes.object.isRequired,
-  itemsActions: React.PropTypes.object.isRequired,
-  linesActions: React.PropTypes.object.isRequired,
-  projectActions: React.PropTypes.object.isRequired,
-  catalog: React.PropTypes.object
+  areaActions: PropTypes.object.isRequired,
+  holesActions: PropTypes.object.isRequired,
+  itemsActions: PropTypes.object.isRequired,
+  linesActions: PropTypes.object.isRequired,
+  projectActions: PropTypes.object.isRequired,
+  catalog: PropTypes.object
 };
