@@ -106,6 +106,7 @@ export const VIEWER3D_ACTIONS = {
 };
 
 export const ITEMS_ACTIONS = {
+  SELECT_ITEM,
   SELECT_TOOL_DRAWING_ITEM,
   UPDATE_DRAWING_ITEM,
   END_DRAWING_ITEM,
@@ -136,11 +137,11 @@ export const LINE_ACTIONS = {
   BEGIN_DRAGGING_LINE,
   UPDATE_DRAGGING_LINE,
   END_DRAGGING_LINE
-}
+};
 
 export const AREA_ACTIONS = {
   SELECT_AREA
-}
+};
 
 export const SCENE_ACTIONS = {
   ADD_LAYER,
