@@ -1,4 +1,5 @@
-import React, {PropTypes, Component} from 'react';
+import React, {Component} from 'react';
+import PropTypes from 'prop-types';
 import {bindActionCreators} from 'redux';
 import {connect} from 'react-redux';
 
@@ -25,11 +26,11 @@ class ReactPlanner extends Component {
     projectActions.initCatalog(catalog);
   }
 
-  componentWillReceiveProps(nextProps){
+  componentWillReceiveProps(nextProps) {
     let {stateExtractor, state, projectActions, catalog} = nextProps;
     let plannerState = stateExtractor(state);
     let catalogReady = plannerState.getIn(['catalog', 'ready']);
-    if(!catalogReady) {
+    if (!catalogReady) {
       projectActions.initCatalog(catalog);
     }
   }
@@ -51,6 +52,7 @@ ReactPlanner.propTypes = {
   height: PropTypes.number.isRequired,
   stateExtractor: PropTypes.func.isRequired,
   toolbarButtons: PropTypes.array,
+  sidebarComponents: PropTypes.array,
   customContents: PropTypes.object,
 };
 
@@ -71,6 +73,7 @@ ReactPlanner.defaultProps = {
   allowProjectFileSupport: true,
 
   toolbarButtons: [],
+  sidebarComponents: [],
   customContents: {},
 };
 
